@@ -3,7 +3,7 @@ import os,sys
 
 def parse_file( fname ):
 	
-	f = open( os.path.dirname(sys.argv[0])+"/libpiano/"+fname, 'r' )
+	f = open( sys.path[0]+"/libpiano/"+fname, 'r' )
 	lines = f.readlines()
 	f.close()
 	lines = cleanup( lines )
