@@ -1,46 +1,60 @@
 #Import, of course
-import sys
+import sys,os
 
 from libpiano.pandora import Pandora
-from PyQt4 import QtCore
+from PySide import QtCore
 
 class RadioPlayer(QtCore.QThread): #Main radio class
-	
 	def __init__( self, Parent=None ):
 		self.os = self.get_product()
 		self.playlist = []
-		self.state = 0 
-
+		self.state = 0
+		print self.os
 		if self.os == "RX-51": #Check for N900 or Diablo
 			from libpiano.MAFWBackend import MAFWBackend
 			self.player = MAFWBackend()
-		else:
+		elif self.os == "MeeGo":
+			from libpiano.GstBackend import GstBackend
+			self.player = GstBackend()
+		#	print "Here"
+		elif self.os == "RX-44":
 			from libpiano.OSSOBackend import OSSOBackend
 			self.player = OSSOBackend()
+		else:
+			from libpiano.MPlayerBackend import MPlayerBackend
+			self.player = MPlayerBackend()
+
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("eof"), self.sigEOF)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("state_change(int)"), self.stateChange)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("pos_changed(int,int)"), self.updateTime)
-		self.format = 'mp3'
+		self.format = 'aacplus'
+		self.protocol_version = 0
+		self.proxy = ""
 
 		QtCore.QThread.__init__(self)
 
 	def run(self):
-		self.pandora = Pandora( self.format )
+		self.pandora = Pandora( self.format, self.protocol_version )
+		if len(self.proxy) > 0:
+		    self.pandora.set_proxy(self.proxy)
 		print "Radio Started."
 
 	def get_product( self ): #Find Product ID
-		try:                                                               
-			lines = open("/proc/component_version", "r").readlines()       
-		except:                                                            
-			lines = []                                                     
-			                                           
-		product = "?"                                                      
-		for line in lines:                                                 
-			line = line.strip()                                            
-			if (line.startswith("product")):                               
-				parts = line.split()                                       
-				product = parts[1].strip()                                 
-				break                                                      
+		try:
+			lines = open("/proc/component_version", "r").readlines()
+		except:
+			try: lines = open("/etc/meego-release", "r").readlines()
+			except: lines = []
+
+		product = "?"
+		for line in lines:
+			line = line.strip()
+			if (line.startswith("product")):
+				parts = line.split()
+				product = parts[1].strip()
+				break
+			elif (line.startswith("MeeGo")):
+				product = "MeeGo"
 		#end for
 		return product
 
@@ -59,7 +73,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 
 	def setVolume( self, volume ):
 		self.player.set_volume( volume )
-		
+
 	def createStation( self, stationId ): #Create a station at Pandora
 		ret = self.pandora.createStation( stationId )
 		return ret["stationId"]
@@ -80,7 +94,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 
 	def startPlayBack ( self ): #Resume after Pause
 		self.player.play()
-		
+
 	def sigEOF( self ):
 		print "EOF called."
 		self.emit(QtCore.SIGNAL("EOF"))
